@@ -8,6 +8,5 @@ Created on Mon Jan 10 15:57:46 2022
 """
 from ._qc_plotting import qc_plotting
 from ._gene_density_plot import gene_density_plot
-from ._gene_tsne import gene_tsne
-from ._gene_umap import gene_umap
+from ._gene_embedding import gene_embedding
 from ._isoform_qc_plot import isoform_qc_plot
\ No newline at end of file
